/*
Phi-1 shield for Arduino
Test program: car backing/reverse obstacle sensor with sonic ranger
This program is fairly long. For a nutshell version of this program to study with, visit http://liudr.wordpress.com/phi-1-shield/

Programmed by Dr. John Liu
Revision: 02/12/2011
Commerical use without authorization is prohibited.
Find details of the Phi-1 shield, Phi-2 shield or contact Dr. Liu at http://liudr.wordpress.com/phi-1-shield/
All rights reserved.
*/

long sonic_ranger_read(int gate_pin) // Reads and returns the time pulse.
{
  // The PING))) is triggered by a HIGH pulse of 2 or more microseconds.
  // Give a short LOW pulse beforehand to ensure a clean HIGH pulse:
  //  temp2=millis();
  long duration;
  pinMode(gate_pin, OUTPUT);
  digitalWrite(gate_pin, LOW);
  delayMicroseconds(2);
  digitalWrite(gate_pin, HIGH);
  delayMicroseconds(15);
  digitalWrite(gate_pin, LOW);
  delayMicroseconds(20);
  // The same pin is used to read the signal from the PING))): a HIGH
  // pulse whose duration is the time (in microseconds) from the sending
  // of the ping to the reception of its echo off of an object.
  pinMode(gate_pin, INPUT);
  duration = pulseIn(gate_pin, HIGH);
  return duration;
}

void ranger_display_distance(long duration)
{
  char msg[10];
  float mm;
  if (duration>23200)
  {
    delayMicroseconds(2000); // Delay before the next measurement.
    lcd.setCursor(10,0);
    lcd.print("OUT OF");
    render_double_bar(2000, 2000);
    lcd.setCursor(10,1);
    lcd.print("RANGE!");
  }

  // convert the time into a distance
  mm = (float)(duration) / 5.80;
        
  lcd.setCursor(11,0);
  sprintf(msg,"%01d\'%02d\"",int((mm/25.4)/12),int(mm/25.4)%12);
  lcd.print(msg);
  render_double_bar(mm, 2000);
  sprintf(msg,"%4dmm",int(mm));
  lcd.setCursor(10,1);
  lcd.print(msg);
}

int sonic_ranger(int gate_pin) // Reads and displays distance with audio alert. It returns 0 normally and -1 when user presses a key.
{
  long duration, time;
  float mm;
  time=millis();
  if (audio_alert) tone(buzzer,440);
  duration=sonic_ranger_read(gate_pin);
  mm = (float)(duration) / 5.80;
  ranger_display_distance(duration);
  delay(int(mm/on_divider));

  noTone(buzzer);// After wait, turn off buzzer

  delay(int(mm/off_divider));
  return 0;
}


